@@ -105,7 +105,7 @@ sub token_request {
 
 	my $url = "https://$client_id:$secret\@www.reddit.com/api/v1/access_token";
 
-    	my $ua = LWP::UserAgent->new(user_agent => $useragent);
+    	my $ua = LWP::UserAgent->new(agent => $useragent);
 	my $req = HTTP::Request->new(POST => $url);
 	$req->header('content-type' => 'application/x-www-form-urlencoded');
 
