@@ -11,19 +11,22 @@ use fields qw/over18 header_img created_utc header_title header_size
               description display_name created url title subscribers
               public_description/;
 
-sub links {
+# thse functions are currently unavailable
+sub get_links {
     my ($self, %param) = @_;
-    return $self->{session}->fetch_links(subreddit => $self->{url}, %param);
+    return $self->{session}->get_links(subreddit => $self->{display_name}, %param);
 }
 
 sub submit_link {
-    my ($self, $title, $url) = @_;
-    $self->{session}->submit_link(title => $title, url => $url, sr => $self->{title}, kind => 'link');
+    my ($self, %param) = @_;
+    $param{subreddit} = $self->{display_name};
+    return $self->{session}->submit_link(%param);
 }
 
 sub submit_text {
-    my ($self, $title, $text) = @_;
-    $self->{session}->submit_text(title => $title, text => $text, sr => $self->{title}, kind => 'text');
+    my ($self, %param) = @_;
+    $param{subreddit} = $self->{display_name};
+    return $self->{session}->submit_text(%param);
 }
 
 1;
