@@ -6,8 +6,9 @@ use Carp;
 
 use List::Util qw/first/;
 
-our @BOOL_FIELDS = qw/is_self likes clicked saved hidden over_18 over18
-                      has_mail has_mod_mail is_mod is_gold was_comment new/;
+our @BOOL_FIELDS = qw/is_self likes clicked saved hidden over_18 over18 edited
+                      has_mail has_mod_mail is_mod is_gold was_comment new
+		      /;
 
 
 use fields qw/session name id/;
